@@ -2,8 +2,9 @@ use 5.14.0;
 
 package Map::Metro::Plugin::Map::Lille;
 
-our $VERSION = '0.1002'; # VERSION
 # ABSTRACT: Map::Metro map for Lille
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1003';
 
 use Moose;
 with 'Map::Metro::Plugin::Map';
@@ -32,22 +33,21 @@ Map::Metro::Plugin::Map::Lille - Map::Metro map for Lille
 
 
 
-=begin HTML
+=begin html
 
-<p><img src="https://img.shields.io/badge/perl-5.16+-brightgreen.svg" alt="Requires Perl 5.16+" /> <a href="https://travis-ci.org/Csson/p5-Map-Metro-Lille"><img src="https://api.travis-ci.org/Csson/p5-Map-Metro-Lille.svg?branch=master" alt="Travis status" /></a></p>
+<p>
+<img src="https://img.shields.io/badge/perl-5.16+-blue.svg" alt="Requires Perl 5.16+" />
+<a href="https://travis-ci.org/Csson/p5-Map-Metro-Lille"><img src="https://api.travis-ci.org/Csson/p5-Map-Metro-Lille.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/release/CSSON/Map-Metro-Plugin-Map-Lille-0.1003"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Map-Metro-Plugin-Map-Lille/0.1003" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Map-Metro-Plugin-Map-Lille%200.1003"><img src="http://badgedepot.code301.com/badge/cpantesters/Map-Metro-Plugin-Map-Lille/0.1003" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-69.2%-red.svg" alt="coverage 69.2%" />
+</p>
 
-=end HTML
-
-
-=begin markdown
-
-![Requires Perl 5.16+](https://img.shields.io/badge/perl-5.16+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Map-Metro-Lille.svg?branch=master)](https://travis-ci.org/Csson/p5-Map-Metro-Lille)
-
-=end markdown
+=end html
 
 =head1 VERSION
 
-Version 0.1002, released 2015-05-09.
+Version 0.1003, released 2019-09-29.
 
 =head1 SYNOPSIS
 
@@ -92,7 +92,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
